use std::path::Path;

use serde::Serialize;

use crate::config::Config;
use crate::error::CustomError;
use crate::intermediate::ITableRow;

use super::macros::render;
use super::table_cell::RenderTableCell;

#[derive(Debug, Serialize)]
#[serde(tag = "type")]
#[serde(rename = "table_row")]
pub(crate) struct RenderTableRow {
    children: Vec<RenderTableCell>,
}

render!(
    RenderTableRow,
    ITableRow,
    original,
    config,
    output_directory,
    output_file,
    {
        let children = {
            let mut ret = Vec::new();
            for obj in original.children.iter() {
                ret.push(RenderTableCell::new(
                    config,
                    output_directory,
                    output_file,
                    obj,
                )?);
            }
            ret
        };

        Ok(RenderTableRow { children })
    }
);
